/*
 * Asterisk -- An open source telephony toolkit.
 *
 * Copyright (C) 1999 - 2005, Digium, Inc.
 *
 * Mark Spencer <markster@digium.com>
 *
 * See http://www.asterisk.org for more information about
 * the Asterisk project. Please do not directly contact
 * any of the maintainers of this project for assistance;
 * the project provides a web site, mailing lists and IRC
 * channels for your use.
 *
 * This program is free software, distributed under the terms of
 * the GNU General Public License Version 2. See the LICENSE file
 * at the top of the source tree.
 */

/*! \file
 *
 * \brief Applications connected with Manager engine
 *
 * \author Mark Spencer <markster@digium.com>
 *
 * \ingroup applications
 */

#include "asterisk.h"

ASTERISK_FILE_VERSION(__FILE__, "$Revision: 153365 $")

#include "asterisk/channel.h"
#include "asterisk/module.h"

/*** DOCUMENTATION
	<application name="NoAMI" language="en_US">
		<synopsis>
			Tell Asterisk to not send Manager Event for the current call
		</synopsis>
		<syntax />
		<description>
			<para>This application will tell Asterisk not send Manager Event for the current call.</para>
		</description>
	</application>
 ***/

static char *noami_app = "NoAMI";

static int noami_exec(struct ast_channel *chan, void *data)
{
	chan->send_manager = 0;

	return 0;
}

static int unload_module(void)
{
	return ast_unregister_application(noami_app);
}

static int load_module(void)
{
	if (ast_register_application_xml(noami_app, noami_exec))
		return AST_MODULE_LOAD_FAILURE;
	return AST_MODULE_LOAD_SUCCESS;
}

AST_MODULE_INFO_STANDARD(ASTERISK_GPL_KEY, "Tell Asterisk to not send Manager Event for the current call");
